pub fn parse_cpp_file(
file: &ProjectFile,
source: &str,
tree: &Tree,
) -> ParsedFileExpand description
Extract file under the dialect its own path selects.
pub fn parse_cpp_file(
file: &ProjectFile,
source: &str,
tree: &Tree,
) -> ParsedFileExtract file under the dialect its own path selects.