pub fn is_cpp_compile_context_input(file: &ProjectFile) -> boolExpand description
Whether file is the workspace compilation database consumed by
CppCompileContexts::load.
pub fn is_cpp_compile_context_input(file: &ProjectFile) -> boolWhether file is the workspace compilation database consumed by
CppCompileContexts::load.