pub struct CppCompileContext {
pub project_include_roots: Vec<PathBuf>,
pub system_include_roots: Vec<PathBuf>,
pub forced_includes: Vec<PathBuf>,
pub defined_macros: HashSet<String>,
/* private fields */
}Expand description
The compiler configuration Bifrost can safely use for one source file.
This is deliberately narrower than a compiler invocation. It records only
context that later semantic diagnostics need and never executes command.
Fields
project_include_roots: Vec<PathBuf>system_include_roots: Vec<PathBuf>forced_includes: Vec<PathBuf>defined_macros: HashSet<String>Implementations
Sourceimpl CppCompileContext
impl CppCompileContext
Sourcepub fn external_angle_include_roots<'a>(
&'a self,
workspace_root: &'a Path,
) -> impl Iterator<Item = &'a Path> + 'a
pub fn external_angle_include_roots<'a>( &'a self, workspace_root: &'a Path, ) -> impl Iterator<Item = &'a Path> + 'a
Explicit external roots in compiler search order for angle includes.