pub struct LexicalScopeCache { /* private fields */ }Expand description
One scan’s memo of lexical scope reconstructions for one file, keyed by the reconstruction’s anchor range and flags, with the file’s recovered namespace regions that the key and the reconstruction both read.