pub struct MacroLexicalReferences {
pub references: Vec<(Range<usize>, MacroLexicalBinding)>,
pub truncated: bool,
pub cancelled: bool,
}Expand description
Lexical macro references are query-local facts. A cancelled or bounded walk is kept distinct from a complete empty enumeration so authoritative inverse callers can preserve their completeness status.
Fields
references: Vec<(Range<usize>, MacroLexicalBinding)>truncated: boolcancelled: boolTrait Implementations
Sourceimpl Clone for MacroLexicalReferences
impl Clone for MacroLexicalReferences
Sourcefn clone(&self) -> MacroLexicalReferences
fn clone(&self) -> MacroLexicalReferences
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MacroLexicalReferences
impl Debug for MacroLexicalReferences
Sourceimpl Default for MacroLexicalReferences
impl Default for MacroLexicalReferences
Sourcefn default() -> MacroLexicalReferences
fn default() -> MacroLexicalReferences
Returns the “default value” for a type. Read more
impl Eq for MacroLexicalReferences
Sourceimpl PartialEq for MacroLexicalReferences
impl PartialEq for MacroLexicalReferences
impl StructuralPartialEq for MacroLexicalReferences