cpp_is_range_for_binding_name

Function cpp_is_range_for_binding_name 

pub fn cpp_is_range_for_binding_name(node: Node<'_>) -> bool
Return whether node is one of the names declared by a range-for declarator. Follow only declarator fields. This keeps identifiers in array bounds and attributes in the range-for header as references.