compile_commands.json ingestion.
analyzer/cpp/mod.rs keeps the OnceLock<CppCompileContexts> that memoizes
CppCompileContexts::load per analyzer generation; the database format and
the argument grammar are here.
Structs
- CppCompile
Context - The compiler configuration Bifrost can safely use for one source file.
- CppCompile
Contexts
Enums
- CppExternal
Include Resolution - What all compile configurations for one source prove about an angle include.