Module compile_context

Module compile_context 

compile_commands.json ingestion.

analyzer/cpp/mod.rs keeps the OnceLock<CppCompileContexts> that memoizes CppCompileContexts::load per analyzer generation; the database format and the argument grammar are here.

Structs

CppCompileContext
The compiler configuration Bifrost can safely use for one source file.
CppCompileContexts