pub struct CppCompileContext {
pub project_include_roots: Vec<PathBuf>,
pub system_include_roots: Vec<PathBuf>,
pub forced_includes: Vec<PathBuf>,
pub defined_macros: HashSet<String>,
}Expand description
The compiler configuration Bifrost can safely use for one source file.
This is deliberately narrower than a compiler invocation. It records only
context that later semantic diagnostics need and never executes command.
Fields
project_include_roots: Vec<PathBuf>system_include_roots: Vec<PathBuf>forced_includes: Vec<PathBuf>defined_macros: HashSet<String>Trait Implementations
Sourceimpl Clone for CppCompileContext
impl Clone for CppCompileContext
Sourcefn clone(&self) -> CppCompileContext
fn clone(&self) -> CppCompileContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CppCompileContext
impl Debug for CppCompileContext
impl Eq for CppCompileContext
Sourceimpl PartialEq for CppCompileContext
impl PartialEq for CppCompileContext
impl StructuralPartialEq for CppCompileContext