pub fn cpp_header_body_implementation_file<'a>(
left: &'a ProjectFile,
right: &'a ProjectFile,
) -> Option<&'a ProjectFile>Expand description
Which of left/right the include evidence would read as the header, if
either. The analysis wrapper uses this to decide which file’s imports to read
before paying for them.